@@ -8,6 +8,8 @@ import os
 import json
 import time
 
+from .Config import Config
+
 class Analyzer(object):
     """ Analyzes Latte log data """
 
@@ -18,13 +20,15 @@ class Analyzer(object):
         if len(args) == 1:
             try:
                 log_time = int(args[0], 10)
-                self.since = time.time() - log_time
+                if log_time > 0:
+                    self.since = time.time() - log_time
             except:
                 print 'Cannot convert time argument to integer'
         elif len(args) == 2 and args[1] in ['d', 'w', 'm']:
             try:
                 log_time = int(args[0], 10)
-                converted = True
+                if log_time > 0:
+                    converted = True
             except:
                 print 'Cannot convert time argument to integer'
             if converted:
@@ -108,8 +112,8 @@ class Analyzer(object):
         """ Loads logs from log files and stores them in memory """
 
         # Get a list of log files available
-        logsPath = os.path.join(self.config['appPath'], \
-                                self.config['statsPath'])
+        logsPath = os.path.join(self.config.get('app_path'), \
+                                self.config.get('stats_path'))
         logFiles = os.listdir(logsPath)
         if not logFiles:
             return False
@@ -152,10 +156,4 @@ class Analyzer(object):
             return '%ds' % seconds
 
 if __name__ == '__main__':
-    # FIXME: At this point it should load user-defined configs, not hardcoded
-    configs = {}
-    configs['appPath'] = os.path.expanduser('~/.latte')
-    configs['statsPath'] = 'stats/'
-    configs['sleepTime'] = 5
-    configs['autosaveTime'] = 3600
-    Analyzer(configs).run()
+    Analyzer(Config()).run()
